diff src/org/tmatesoft/hg/core/HgException.java @ 367:2fadf8695f8a

Use 'revision index' instead of the vague 'local revision number' concept in the API
author Artem Tikhomirov <tikhomirov.artem@gmail.com>
date Fri, 16 Dec 2011 15:37:27 +0100
parents 678e326fd27c
children 8107b95f4280
line wrap: on
line diff
--- a/src/org/tmatesoft/hg/core/HgException.java	Fri Dec 16 04:43:18 2011 +0100
+++ b/src/org/tmatesoft/hg/core/HgException.java	Fri Dec 16 15:37:27 2011 +0100
@@ -47,16 +47,33 @@
 	}
 
 	/**
 	 * @return not {@link HgRepository#BAD_REVISION} only when local revision number was supplied at the construction time
 	 */
-	public int getRevisionNumber() {
+	public int getRevisionIndex() {
 		return revNumber;
 	}
 
-	public HgException setRevisionNumber(int rev) {
+	/**
+	 * @deprecated use {@link #getRevisionIndex()}
+	 */
+	@Deprecated
+	public int getRevisionNumber() {
+		return getRevisionIndex();
+	}
+	
+
+	public HgException setRevisionIndex(int rev) {
 		revNumber = rev;
 		return this;
 	}
+	
+	/**
+	 * @deprecated use {@link #setRevisionIndex(int)}
+	 */
+	@Deprecated
+	public final HgException setRevisionNumber(int rev) {
+		return setRevisionIndex(rev);
+	}
 
 	/**
 	 * @return non-null only when revision was supplied at construction time
@@ -47,16 +47,33 @@
 
 	/**
-	 * @return not {@link HgRepository#BAD_REVISION} only when local revision number was supplied at the construction time
+	 * @return not {@link HgRepository#BAD_REVISION} only when local revision index was supplied at the construction time
 	 */